# *con*Strain

*con*Strain is an image analysis software which calculates true stress / true strain curves for tensile material tests in engineering.
The method computes strain from the specimen's contour. 

## Description
*con*Strain is applicable to axis-symmetric specimens under tensile loading. Here, it calcualates accurate true stress and true strain. Automated image analysis also yields the curvature of the necking region, such that the effects of stress triaxiality are accounted for. In contrast to Digital Image Correlation (DIC), *con*Strain does not require a contrast pattern, but instead uses a backlight source behind the specimen, such that a shadow image is obtained.

*con*Strain is optimized for analyzing materials with Poisson ratio of 1/2, typically metals undergoing isochorig plastic flow.  It is suboptimal for analyzing small, elastic deformations. In that case, other method ssuch as DIC are better suited. However, *con*Strain really shines when deformation are large as it becomes more accurate with increasing strain.

## Installation
*con*Strain is written in Python 3. It has been developed on Windows 10 using WinPython 3.7.7.1.
- Install WinPython 3.7.7.1 64bit (newer versions might also work -- but you are on your own)
- Install the following Python packages inside the winPython environment:
    - scikit-image
    - opencv-python
    - note: Installation of additional Python packages is done by opening WinPython's Powershell and then using pip, e.g.:
      - pip install scikit-image
      - pip install opencv-python
- extract the contents of the *con*Strain archive into a folder of your choice, termed the *installation directory* henceforth.

## usage
- open WinPython's PowerShell
- Go to the *installation directory*, and to the *sample\brass* directory below that.
- execute:
    `python ..\..\conStrain.py`
- this reads in the configuration settings from file `constrain.ini` and iterates over all images present in the sample directory, calculating the cross section diameter and the radius of neck curvature. Finally, the collected data is displayed and saved. The resulting file, `strain.txt`, contains these columns:
        - (1) frame index,
        - (2) true strain
        - (3) diameter in px
        - (4) radius of neck
        
## post-processing for true stress / true equivalent strain data
To obtain a plot of true stress vs. true strain curves from an experiment, do the following:

- have a file with time and force columns in the same directory
- see the commented section in `constrain.ini` for details
- execute:
    `python ..\..\align_stress_strain.py`
       
## Acknowledgments
*con*Strain uses many open-source packages.
    





