# -*- coding: utf-8 -*-
"""
Created on Thu Sep  3 23:17:27 2020

@author: Georg

plot stress vs. strain with Bridgeman correction

"""

import numpy as np
import matplotlib.pyplot as plt
import glob, os
from scipy import interpolate
import triaxiality

#-----------
path = r"sample_data\FEM_notched"
#path = r"C:\Users\Georg\OneDrive - Fraunhofer\Documents\Projekte\edge-strain\Simulation\Herme_TriaxR2d5\simu_new\images"
path = r"C:\Users\Georg\OneDrive - Fraunhofer\Documents\FEM\LS-Dyna\Edge_Strain\M8L8_mesh_new\images"
force_filename ="force.csv"
nskip_force = 2
dt_strain = 0.01
D0 = 3.0





# load force file
os.chdir(path)
# lines below for FEM verification
data = np.genfromtxt(force_filename, delimiter=",", skip_header=nskip_force)
time = data[:,0]
force  = data[:,1] * 2 * np.pi # if axis-symmetric
dt_force = time[1] - time[0]
print("force time axis covers %g to %g" % (time[0], time[-1]))

# load simulation strain file
#data = np.genfromtxt("plastic_strain.csv", delimiter=",", skip_header=nskip_force)
#time_sim = data[:,0]
#eps_sim = data[:,1]

# load simulation von mises stress file
#data = np.genfromtxt("sigma_vm.csv", delimiter=",", skip_header=nskip_force)
#time_sim = data[:,0]
#sigma_sim = data[:,1]

# load simulation von axial stress file
#data = np.genfromtxt("y_stress.csv", delimiter=",", skip_header=nskip_force)
#sigma_ax = data[:,1]

# load simulation triax file
#data = np.genfromtxt("triax.csv", delimiter=",", skip_header=nskip_force)
#triax_sim = data[:,1]

strain_data = np.genfromtxt("strain.txt")
index = strain_data[:,0]
eps_eq = strain_data[:,1]
dias = strain_data[:,2]
notch_radii = strain_data[:,3]
b = triaxiality.bridgman_function(dias, notch_radii)
triax = triaxiality.triax_function(dias, notch_radii)

index *= dt_strain
print("strain time axis covers %g to %g" % (index[0], index[-1]))

#plt.plot(index, eps_eq)
#plt.plot(time_sim, eps_sim)
#plt.show()

#plt.plot(index, triax, label="conStrain triax")
#plt.plot(time_sim, triax_sim, label="simulation triax")
#plt.legend()
#plt.show()


def trim_high_end(x1, y1, x2, y2):
    """
    given two array pairs, trim onto the same x range
    """
    
    swap = False
    
    if x1[-1] < x2[-1]: # sort array pairs such that x2 extends to smaller values than x1
        swap = True
        x1, x2 = x2, x1
        y1, y2 = y2, y1
        
    # need to trim x1
    limit = x2[-1]
    print("upper limit is", limit)
    trim_index = np.argmax(x1 > limit)
    print("trim index is:", trim_index)
    x1 = x1[:trim_index]
    y1 = y1[:trim_index]
    
    if swap:
        return x2, y2, x1, y1
    else:
        return x1, y1, x2, y2
    
def find_limits(t1, t2):
    """ return common time range between to time axex
    """
    
    # upper end only for now
    high = min(t1[-1], t2[-1])
    return high
    
    
def power_law_plasticity(strain):
    """ return power law plastic strain according to LS-Dyna material model Nr. 18"
    """
    
    E = 110.32
    pr = 0.33
    K = 0.6043
    n = 0.107014
    
    eps_ela = (E/K)**(1/(n-1))
    print("elastic strain at yield is: ", eps_ela)
    
    sigma = K * (eps_ela + strain)**n
    
    
    
    return eps_ela + strain, sigma
    

time, force, index, eps_eq = trim_high_end(time, force, index, eps_eq)
print("common time range: ", time[0], time[-1])

# interpolate strain data -- with index time base onto force time axis
print("index range again:", index[0], index[-1])
f = interpolate.interp1d(index, eps_eq)
eps_eq = f(time)
f = interpolate.interp1d(index, b)
b = f(time)
f = interpolate.interp1d(index, triax)
triax = f(time)



diameter = D0/np.exp(0.5 * eps_eq)
area = 0.25 * np.pi * diameter**2
stress = force / area


#plt.plot(eps_eq, triax, label="conStrain triax")
#plt.plot(eps_sim, triax_sim, label="simulation triax")
#plt.plot(time, eps_eq, label="conStrain strain")
#plt.plot(time_sim, eps_sim, label="simulation strain")
#plt.legend()
#plt.show()

#plt.plot(time, force, "r.", label="force/time")
plt.plot(eps_eq, stress, "rx", label="uncorrected Cauchy stress")
plt.plot(eps_eq, stress * b, label ="Bridgman corrected Cauchy stress")
mat_strain, mat_stress  = power_law_plasticity(eps_eq)
plt.plot(mat_strain, mat_stress, label="material model")
#plt.plot(eps_eq, power_law_plasticity(eps_eq), label="material model")
#plt.plot(eps_sim, sigma_sim, "r.", label="simulation von-Mises stress")
#plt.plot(eps_sim, sigma_ax, "g.", label="simulation axial stress")
#plt.plot(eps_eq, eps_sim, "r.", label="conStrain vs. plastic strain")
plt.title("Edge-Strain Validation")
plt.xlabel("true strain [-]")
plt.ylabel("true stress [GPa]")
plt.legend()
plt.grid()
plt.show()

#print(data)


